package com.pdaaphm.system.mapper;

import java.util.List;
import com.pdaaphm.system.domain.TDataProcess;

/**
 * 数据处理Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-20
 */
public interface TDataProcessMapper 
{
    /**
     * 查询数据处理
     * 
     * @param id 数据处理主键
     * @return 数据处理
     */
    public TDataProcess selectTDataProcessById(Long id);

    /**
     * 查询数据处理列表
     * 
     * @param tDataProcess 数据处理
     * @return 数据处理集合
     */
    public List<TDataProcess> selectTDataProcessList(TDataProcess tDataProcess);

    /**
     * 新增数据处理
     * 
     * @param tDataProcess 数据处理
     * @return 结果
     */
    public int insertTDataProcess(TDataProcess tDataProcess);

    /**
     * 修改数据处理
     * 
     * @param tDataProcess 数据处理
     * @return 结果
     */
    public int updateTDataProcess(TDataProcess tDataProcess);

    /**
     * 删除数据处理
     * 
     * @param id 数据处理主键
     * @return 结果
     */
    public int deleteTDataProcessById(Long id);

    /**
     * 批量删除数据处理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTDataProcessByIds(Long[] ids);

    List<TDataProcess> selectPreprocessDataList(TDataProcess tDataProcess);
}
